//
//  YHInformationFillCell.swift
//  galaxy
//
//  Created by edy on 2024/4/11.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AttributedString

class YHInformationFillCell: UITableViewCell {
    
    static let cellReuseIdentifier = "YHInformationFillCell"
    static let unreadPointWidth = 6.0
    
    var whiteView:UIView!
    var titleLabel:UILabel!
    var detailLabel:UILabel!
    var unreadPointView:UIView!
    var bottomBtn:UIButton!
    var lineView:UIView!

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        contentView.backgroundColor = UIColor(hex:0xF8F8F8)

        whiteView = UIView()
        whiteView.backgroundColor = .white
        whiteView.layer.cornerRadius = 6.0
        whiteView.clipsToBounds = true
        contentView.addSubview(whiteView)
        
        titleLabel = UILabel()
        titleLabel.textColor = UIColor(hex: 0x222222)
        titleLabel.textAlignment = .left
        titleLabel.font = UIFont.PFSC_M(ofSize:17)
        titleLabel.text = "资料填写提醒".local
        whiteView.addSubview(titleLabel)
        
        unreadPointView = UIView()
        unreadPointView.backgroundColor = UIColor(hex:0xF81D22)
        unreadPointView.layer.cornerRadius = Self.unreadPointWidth/2.0
        unreadPointView.clipsToBounds = true
        whiteView.addSubview(unreadPointView)

        
        detailLabel = UILabel()
        detailLabel.textAlignment = .left
        detailLabel.numberOfLines = 0
        whiteView.addSubview(detailLabel)
        
        lineView = UIView()
        lineView.backgroundColor = UIColor(hex:0xF8F8F8)
        whiteView.addSubview(lineView)

        bottomBtn = UIButton()
        bottomBtn.setTitle("去填写".local, for: .normal)
        bottomBtn.setTitleColor(UIColor(hex: 0x3570DC), for: .normal)
        bottomBtn.titleLabel?.font = .PFSC_R(ofSize: 14)
        bottomBtn.addTarget(self, action: #selector(didBottomBtnClicked), for: .touchUpInside)
        whiteView.addSubview(bottomBtn)
        
        whiteView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
            make.top.bottom.equalToSuperview()
        }
        
        titleLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.top.equalToSuperview().offset(16)
            make.height.equalTo(24.0)
        }
        
        unreadPointView.snp.makeConstraints { make in
            make.width.height.equalTo(Self.unreadPointWidth)
            make.left.equalTo(titleLabel.snp.right).offset(4)
            make.centerY.equalTo(titleLabel)
            make.right.lessThanOrEqualToSuperview().offset(-16)
        }
        
        detailLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
            make.top.equalTo(titleLabel.snp.bottom).offset(12)
        }
        
        lineView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(detailLabel.snp.bottom).offset(16)
            make.height.equalTo(1)
        }
        
        bottomBtn.snp.makeConstraints { make in
            make.top.equalTo(lineView.snp.bottom)
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(52)
        }
        
        updateModel()
    }
    
    @objc func didBottomBtnClicked() {
        
    }
    
    func updateModel() {
        
        let text1: ASAttributedString = .init("林先生，您好，您尚有20%内容未填写，请到", .font(UIFont.PFSC_R(ofSize: 14)), .foreground(UIColor(hex: 0x121A26, alpha: 0.7)))
        
        let text2: ASAttributedString = .init("服务中心-资料上传", .font(UIFont.PFSC_R(ofSize: 14)),.foreground(UIColor(hex: 0x3570DC)), .action {
            
        })
        let text3: ASAttributedString = .init("去填写，请您尽快完成～", .font(UIFont.PFSC_R(ofSize: 14)),.foreground(UIColor(hex: 0x121A26, alpha: 0.7)))
        
        detailLabel.attributed.text = text1 + text2 + text3
    }

}
